@@ -1,7 +1,7 @@
 # $Author: ddumont $
-# $Date: 2007/10/01 15:27:34 $
+# $Date: 2007/10/26 11:54:56 $
 # $Name:  $
-# $Revision: 1.1 $
+# $Revision: 1.2 $
 
 #    Copyright (c) 2005,2006 Dominique Dumont.
 #
@@ -23,11 +23,28 @@
 
 package Config::Model::Xorg ;
 
+use Config::Model ;
+use Log::Log4perl ;
+
+my $log4perl_conf_file = '/etc/log4config-model.conf' ;
+my $fallback_conf = << 'EOC';
+log4perl.logger.ConfigModel=WARN, A1
+log4perl.appender.A1=Log::Dispatch::File
+log4perl.appender.A1.filename=/tmp/ConfigModel.log
+log4perl.appender.A1.mode=append
+log4perl.appender.A1.layout=Log::Log4perl::Layout::SimpleLayout
+EOC
+
+my $log4perl_conf = -e $log4perl_conf_file ? $log4perl_conf_file
+                  :                          \$fallback_conf ;
+
+Log::Log4perl::init($log4perl_conf) unless Log::Log4perl->initialized ;
+
 # dummy package so CPAN can collect information regarding this module
 
 use vars qw($VERSION) ;
 
-$VERSION = sprintf "%d.%03d", q$Revision: 1.1 $ =~ /(\d+)\.(\d+)/;
+$VERSION = sprintf "%d.%03d", q$Revision: 1.2 $ =~ /(\d+)\.(\d+)/;
 
 =head1 NAME
 
@@ -70,6 +87,62 @@ If you do not have the curses user interface, be sure to read doc
 which explain the basic command of the terminal based interface:
 http://search.cpan.org/dist/Config-Model/TermUI.pm#USER_COMMAND_SYNTAX
 
+=head1 CONSTRUCTOR
+
+=head2 new ()
+
+Returns a Config::Model::Xorg object. This object will load Xorg
+configuration model and C<xorg.conf> data.
+
+=cut
+
+sub new {
+    my $type = shift ;
+
+    my $model = Config::Model -> new() ;
+
+    my $inst = $model->instance (root_class_name => 'Xorg' ,
+				 instance_name   => 'xorg config' ,
+				);
+
+    my $root = $inst -> config_root ;
+
+    my $self = { model => $model,
+		 root => $root ,
+	       } ;
+    bless $self,$type ;
+}
+
+=head1 Methods
+
+=head2 root
+
+Return Xorg root node. I.e. a L<Config::Model::Node> object.
+
+=cut
+
+sub root {
+    my $self = shift;
+    return $self->root ;
+}
+
+=head2 check
+
+Check if Xorg configuration data is correct. Return 1 if yes.
+Raises an exception if some error is found.
+
+=cut
+
+sub check {
+    my $self = shift ;
+
+    # this will exit in case of error
+    my $str = $self->{root} -> dump_tree () ;
+
+    print "xorg config is fine\n";
+    return 1;
+}
+
 =head1 AUTHOR
 
 Dominique Dumont, (ddumont at cpan dot org)
